# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class InboundRoute(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        InboundRoute - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'pattern': 'str',
            'queue': 'UriReference',
            'priority': 'int',
            'skills': 'list[UriReference]',
            'language': 'UriReference',
            'from_name': 'str',
            'from_email': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'pattern': 'pattern',
            'queue': 'queue',
            'priority': 'priority',
            'skills': 'skills',
            'language': 'language',
            'from_name': 'fromName',
            'from_email': 'fromEmail',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._pattern = None
        self._queue = None
        self._priority = None
        self._skills = None
        self._language = None
        self._from_name = None
        self._from_email = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this InboundRoute.
        The globally unique identifier for the object.

        :return: The id of this InboundRoute.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InboundRoute.
        The globally unique identifier for the object.

        :param id: The id of this InboundRoute.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this InboundRoute.


        :return: The name of this InboundRoute.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this InboundRoute.


        :param name: The name of this InboundRoute.
        :type: str
        """
        self._name = name

    @property
    def pattern(self):
        """
        Gets the pattern of this InboundRoute.
        The search pattern that the mailbox name should match.

        :return: The pattern of this InboundRoute.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this InboundRoute.
        The search pattern that the mailbox name should match.

        :param pattern: The pattern of this InboundRoute.
        :type: str
        """
        self._pattern = pattern

    @property
    def queue(self):
        """
        Gets the queue of this InboundRoute.
        The queue to route the emails to.

        :return: The queue of this InboundRoute.
        :rtype: UriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this InboundRoute.
        The queue to route the emails to.

        :param queue: The queue of this InboundRoute.
        :type: UriReference
        """
        self._queue = queue

    @property
    def priority(self):
        """
        Gets the priority of this InboundRoute.
        The priority to use for routing.

        :return: The priority of this InboundRoute.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this InboundRoute.
        The priority to use for routing.

        :param priority: The priority of this InboundRoute.
        :type: int
        """
        self._priority = priority

    @property
    def skills(self):
        """
        Gets the skills of this InboundRoute.
        The skills to use for routing.

        :return: The skills of this InboundRoute.
        :rtype: list[UriReference]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """
        Sets the skills of this InboundRoute.
        The skills to use for routing.

        :param skills: The skills of this InboundRoute.
        :type: list[UriReference]
        """
        self._skills = skills

    @property
    def language(self):
        """
        Gets the language of this InboundRoute.
        The language to use for routing.

        :return: The language of this InboundRoute.
        :rtype: UriReference
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this InboundRoute.
        The language to use for routing.

        :param language: The language of this InboundRoute.
        :type: UriReference
        """
        self._language = language

    @property
    def from_name(self):
        """
        Gets the from_name of this InboundRoute.
        The sender name to use for outgoing replies.

        :return: The from_name of this InboundRoute.
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """
        Sets the from_name of this InboundRoute.
        The sender name to use for outgoing replies.

        :param from_name: The from_name of this InboundRoute.
        :type: str
        """
        self._from_name = from_name

    @property
    def from_email(self):
        """
        Gets the from_email of this InboundRoute.
        The sender email to use for outgoing replies.

        :return: The from_email of this InboundRoute.
        :rtype: str
        """
        return self._from_email

    @from_email.setter
    def from_email(self, from_email):
        """
        Sets the from_email of this InboundRoute.
        The sender email to use for outgoing replies.

        :param from_email: The from_email of this InboundRoute.
        :type: str
        """
        self._from_email = from_email

    @property
    def self_uri(self):
        """
        Gets the self_uri of this InboundRoute.
        The URI for this object

        :return: The self_uri of this InboundRoute.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this InboundRoute.
        The URI for this object

        :param self_uri: The self_uri of this InboundRoute.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Charge(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Charge - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'license_count': 'int',
            'name': 'str',
            'description': 'str',
            'price': 'float',
            'unit_of_measure': 'str',
            'billing_period': 'str',
            'quantity': 'int',
            'included_units': 'int'
        }

        self.attribute_map = {
            'license_count': 'licenseCount',
            'name': 'name',
            'description': 'description',
            'price': 'price',
            'unit_of_measure': 'unitOfMeasure',
            'billing_period': 'billingPeriod',
            'quantity': 'quantity',
            'included_units': 'includedUnits'
        }

        self._license_count = None
        self._name = None
        self._description = None
        self._price = None
        self._unit_of_measure = None
        self._billing_period = None
        self._quantity = None
        self._included_units = None

    @property
    def license_count(self):
        """
        Gets the license_count of this Charge.


        :return: The license_count of this Charge.
        :rtype: int
        """
        return self._license_count

    @license_count.setter
    def license_count(self, license_count):
        """
        Sets the license_count of this Charge.


        :param license_count: The license_count of this Charge.
        :type: int
        """
        self._license_count = license_count

    @property
    def name(self):
        """
        Gets the name of this Charge.


        :return: The name of this Charge.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Charge.


        :param name: The name of this Charge.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Charge.


        :return: The description of this Charge.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Charge.


        :param description: The description of this Charge.
        :type: str
        """
        self._description = description

    @property
    def price(self):
        """
        Gets the price of this Charge.


        :return: The price of this Charge.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this Charge.


        :param price: The price of this Charge.
        :type: float
        """
        self._price = price

    @property
    def unit_of_measure(self):
        """
        Gets the unit_of_measure of this Charge.


        :return: The unit_of_measure of this Charge.
        :rtype: str
        """
        return self._unit_of_measure

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure):
        """
        Sets the unit_of_measure of this Charge.


        :param unit_of_measure: The unit_of_measure of this Charge.
        :type: str
        """
        self._unit_of_measure = unit_of_measure

    @property
    def billing_period(self):
        """
        Gets the billing_period of this Charge.


        :return: The billing_period of this Charge.
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """
        Sets the billing_period of this Charge.


        :param billing_period: The billing_period of this Charge.
        :type: str
        """
        self._billing_period = billing_period

    @property
    def quantity(self):
        """
        Gets the quantity of this Charge.


        :return: The quantity of this Charge.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this Charge.


        :param quantity: The quantity of this Charge.
        :type: int
        """
        self._quantity = quantity

    @property
    def included_units(self):
        """
        Gets the included_units of this Charge.


        :return: The included_units of this Charge.
        :rtype: int
        """
        return self._included_units

    @included_units.setter
    def included_units(self, included_units):
        """
        Sets the included_units of this Charge.


        :param included_units: The included_units of this Charge.
        :type: int
        """
        self._included_units = included_units

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Quote(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Quote - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'purchase_order': 'str',
            'type': 'str',
            'status': 'str',
            'currency': 'str',
            'created_date': 'datetime',
            'last_updated_date': 'datetime',
            'billing_contact_email': 'str',
            'billing_contact_first_name': 'str',
            'billing_contact_last_name': 'str',
            'billing_contact_phone': 'str',
            'include_voice_charges': 'bool',
            'charges': 'list[QuoteCharge]',
            'edge_control_model': 'str',
            'referral_codes': 'list[str]',
            'discount_codes': 'list[str]',
            'sales_partner_code': 'str',
            'is_annual_prepay': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'purchase_order': 'purchaseOrder',
            'type': 'type',
            'status': 'status',
            'currency': 'currency',
            'created_date': 'createdDate',
            'last_updated_date': 'lastUpdatedDate',
            'billing_contact_email': 'billingContactEmail',
            'billing_contact_first_name': 'billingContactFirstName',
            'billing_contact_last_name': 'billingContactLastName',
            'billing_contact_phone': 'billingContactPhone',
            'include_voice_charges': 'includeVoiceCharges',
            'charges': 'charges',
            'edge_control_model': 'edgeControlModel',
            'referral_codes': 'referralCodes',
            'discount_codes': 'discountCodes',
            'sales_partner_code': 'salesPartnerCode',
            'is_annual_prepay': 'isAnnualPrepay',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._purchase_order = None
        self._type = None
        self._status = None
        self._currency = None
        self._created_date = None
        self._last_updated_date = None
        self._billing_contact_email = None
        self._billing_contact_first_name = None
        self._billing_contact_last_name = None
        self._billing_contact_phone = None
        self._include_voice_charges = False
        self._charges = None
        self._edge_control_model = None
        self._referral_codes = None
        self._discount_codes = None
        self._sales_partner_code = None
        self._is_annual_prepay = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Quote.
        The globally unique identifier for the object.

        :return: The id of this Quote.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Quote.
        The globally unique identifier for the object.

        :param id: The id of this Quote.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Quote.


        :return: The name of this Quote.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Quote.


        :param name: The name of this Quote.
        :type: str
        """
        self._name = name

    @property
    def purchase_order(self):
        """
        Gets the purchase_order of this Quote.


        :return: The purchase_order of this Quote.
        :rtype: str
        """
        return self._purchase_order

    @purchase_order.setter
    def purchase_order(self, purchase_order):
        """
        Sets the purchase_order of this Quote.


        :param purchase_order: The purchase_order of this Quote.
        :type: str
        """
        self._purchase_order = purchase_order

    @property
    def type(self):
        """
        Gets the type of this Quote.


        :return: The type of this Quote.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Quote.


        :param type: The type of this Quote.
        :type: str
        """
        allowed_values = ["NEW_SUBSCRIPTION", "AMENDMENT"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def status(self):
        """
        Gets the status of this Quote.


        :return: The status of this Quote.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Quote.


        :param status: The status of this Quote.
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "SUBMITTED", "FROZEN"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def currency(self):
        """
        Gets the currency of this Quote.


        :return: The currency of this Quote.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this Quote.


        :param currency: The currency of this Quote.
        :type: str
        """
        self._currency = currency

    @property
    def created_date(self):
        """
        Gets the created_date of this Quote.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this Quote.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this Quote.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this Quote.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def last_updated_date(self):
        """
        Gets the last_updated_date of this Quote.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_updated_date of this Quote.
        :rtype: datetime
        """
        return self._last_updated_date

    @last_updated_date.setter
    def last_updated_date(self, last_updated_date):
        """
        Sets the last_updated_date of this Quote.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_updated_date: The last_updated_date of this Quote.
        :type: datetime
        """
        self._last_updated_date = last_updated_date

    @property
    def billing_contact_email(self):
        """
        Gets the billing_contact_email of this Quote.


        :return: The billing_contact_email of this Quote.
        :rtype: str
        """
        return self._billing_contact_email

    @billing_contact_email.setter
    def billing_contact_email(self, billing_contact_email):
        """
        Sets the billing_contact_email of this Quote.


        :param billing_contact_email: The billing_contact_email of this Quote.
        :type: str
        """
        self._billing_contact_email = billing_contact_email

    @property
    def billing_contact_first_name(self):
        """
        Gets the billing_contact_first_name of this Quote.


        :return: The billing_contact_first_name of this Quote.
        :rtype: str
        """
        return self._billing_contact_first_name

    @billing_contact_first_name.setter
    def billing_contact_first_name(self, billing_contact_first_name):
        """
        Sets the billing_contact_first_name of this Quote.


        :param billing_contact_first_name: The billing_contact_first_name of this Quote.
        :type: str
        """
        self._billing_contact_first_name = billing_contact_first_name

    @property
    def billing_contact_last_name(self):
        """
        Gets the billing_contact_last_name of this Quote.


        :return: The billing_contact_last_name of this Quote.
        :rtype: str
        """
        return self._billing_contact_last_name

    @billing_contact_last_name.setter
    def billing_contact_last_name(self, billing_contact_last_name):
        """
        Sets the billing_contact_last_name of this Quote.


        :param billing_contact_last_name: The billing_contact_last_name of this Quote.
        :type: str
        """
        self._billing_contact_last_name = billing_contact_last_name

    @property
    def billing_contact_phone(self):
        """
        Gets the billing_contact_phone of this Quote.


        :return: The billing_contact_phone of this Quote.
        :rtype: str
        """
        return self._billing_contact_phone

    @billing_contact_phone.setter
    def billing_contact_phone(self, billing_contact_phone):
        """
        Sets the billing_contact_phone of this Quote.


        :param billing_contact_phone: The billing_contact_phone of this Quote.
        :type: str
        """
        self._billing_contact_phone = billing_contact_phone

    @property
    def include_voice_charges(self):
        """
        Gets the include_voice_charges of this Quote.


        :return: The include_voice_charges of this Quote.
        :rtype: bool
        """
        return self._include_voice_charges

    @include_voice_charges.setter
    def include_voice_charges(self, include_voice_charges):
        """
        Sets the include_voice_charges of this Quote.


        :param include_voice_charges: The include_voice_charges of this Quote.
        :type: bool
        """
        self._include_voice_charges = include_voice_charges

    @property
    def charges(self):
        """
        Gets the charges of this Quote.


        :return: The charges of this Quote.
        :rtype: list[QuoteCharge]
        """
        return self._charges

    @charges.setter
    def charges(self, charges):
        """
        Sets the charges of this Quote.


        :param charges: The charges of this Quote.
        :type: list[QuoteCharge]
        """
        self._charges = charges

    @property
    def edge_control_model(self):
        """
        Gets the edge_control_model of this Quote.


        :return: The edge_control_model of this Quote.
        :rtype: str
        """
        return self._edge_control_model

    @edge_control_model.setter
    def edge_control_model(self, edge_control_model):
        """
        Sets the edge_control_model of this Quote.


        :param edge_control_model: The edge_control_model of this Quote.
        :type: str
        """
        self._edge_control_model = edge_control_model

    @property
    def referral_codes(self):
        """
        Gets the referral_codes of this Quote.


        :return: The referral_codes of this Quote.
        :rtype: list[str]
        """
        return self._referral_codes

    @referral_codes.setter
    def referral_codes(self, referral_codes):
        """
        Sets the referral_codes of this Quote.


        :param referral_codes: The referral_codes of this Quote.
        :type: list[str]
        """
        self._referral_codes = referral_codes

    @property
    def discount_codes(self):
        """
        Gets the discount_codes of this Quote.


        :return: The discount_codes of this Quote.
        :rtype: list[str]
        """
        return self._discount_codes

    @discount_codes.setter
    def discount_codes(self, discount_codes):
        """
        Sets the discount_codes of this Quote.


        :param discount_codes: The discount_codes of this Quote.
        :type: list[str]
        """
        self._discount_codes = discount_codes

    @property
    def sales_partner_code(self):
        """
        Gets the sales_partner_code of this Quote.


        :return: The sales_partner_code of this Quote.
        :rtype: str
        """
        return self._sales_partner_code

    @sales_partner_code.setter
    def sales_partner_code(self, sales_partner_code):
        """
        Sets the sales_partner_code of this Quote.


        :param sales_partner_code: The sales_partner_code of this Quote.
        :type: str
        """
        self._sales_partner_code = sales_partner_code

    @property
    def is_annual_prepay(self):
        """
        Gets the is_annual_prepay of this Quote.


        :return: The is_annual_prepay of this Quote.
        :rtype: bool
        """
        return self._is_annual_prepay

    @is_annual_prepay.setter
    def is_annual_prepay(self, is_annual_prepay):
        """
        Sets the is_annual_prepay of this Quote.


        :param is_annual_prepay: The is_annual_prepay of this Quote.
        :type: bool
        """
        self._is_annual_prepay = is_annual_prepay

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Quote.
        The URI for this object

        :return: The self_uri of this Quote.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Quote.
        The URI for this object

        :param self_uri: The self_uri of this Quote.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Trace(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Trace - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'topic': 'str',
            'timestamp': 'datetime',
            'level': 'str',
            'message': 'str',
            'details': 'object',
            'timestamp_string': 'str',
            'details_string': 'str'
        }

        self.attribute_map = {
            'topic': 'topic',
            'timestamp': 'timestamp',
            'level': 'level',
            'message': 'message',
            'details': 'details',
            'timestamp_string': 'timestampString',
            'details_string': 'detailsString'
        }

        self._topic = None
        self._timestamp = None
        self._level = None
        self._message = None
        self._details = None
        self._timestamp_string = None
        self._details_string = None

    @property
    def topic(self):
        """
        Gets the topic of this Trace.


        :return: The topic of this Trace.
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """
        Sets the topic of this Trace.


        :param topic: The topic of this Trace.
        :type: str
        """
        self._topic = topic

    @property
    def timestamp(self):
        """
        Gets the timestamp of this Trace.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The timestamp of this Trace.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this Trace.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param timestamp: The timestamp of this Trace.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def level(self):
        """
        Gets the level of this Trace.


        :return: The level of this Trace.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this Trace.


        :param level: The level of this Trace.
        :type: str
        """
        allowed_values = ["ERROR", "WARN", "INFO", "DEBUG"]
        if level not in allowed_values:
            raise ValueError(
                "Invalid value for `level`, must be one of {0}"
                .format(allowed_values)
            )
        self._level = level

    @property
    def message(self):
        """
        Gets the message of this Trace.


        :return: The message of this Trace.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this Trace.


        :param message: The message of this Trace.
        :type: str
        """
        self._message = message

    @property
    def details(self):
        """
        Gets the details of this Trace.


        :return: The details of this Trace.
        :rtype: object
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this Trace.


        :param details: The details of this Trace.
        :type: object
        """
        self._details = details

    @property
    def timestamp_string(self):
        """
        Gets the timestamp_string of this Trace.


        :return: The timestamp_string of this Trace.
        :rtype: str
        """
        return self._timestamp_string

    @timestamp_string.setter
    def timestamp_string(self, timestamp_string):
        """
        Sets the timestamp_string of this Trace.


        :param timestamp_string: The timestamp_string of this Trace.
        :type: str
        """
        self._timestamp_string = timestamp_string

    @property
    def details_string(self):
        """
        Gets the details_string of this Trace.


        :return: The details_string of this Trace.
        :rtype: str
        """
        return self._details_string

    @details_string.setter
    def details_string(self, details_string):
        """
        Sets the details_string of this Trace.


        :param details_string: The details_string of this Trace.
        :type: str
        """
        self._details_string = details_string

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class EdgeLine(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeLine - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'schema': 'UriReference',
            'properties': 'dict(str, object)',
            'edge': 'Edge',
            'edge_group': 'EdgeGroup',
            'line_type': 'str',
            'endpoint': 'Endpoint',
            'ip_address': 'str',
            'logical_interface_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'schema': 'schema',
            'properties': 'properties',
            'edge': 'edge',
            'edge_group': 'edgeGroup',
            'line_type': 'lineType',
            'endpoint': 'endpoint',
            'ip_address': 'ipAddress',
            'logical_interface_id': 'logicalInterfaceId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._schema = None
        self._properties = None
        self._edge = None
        self._edge_group = None
        self._line_type = None
        self._endpoint = None
        self._ip_address = None
        self._logical_interface_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EdgeLine.
        The globally unique identifier for the object.

        :return: The id of this EdgeLine.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EdgeLine.
        The globally unique identifier for the object.

        :param id: The id of this EdgeLine.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EdgeLine.


        :return: The name of this EdgeLine.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeLine.


        :param name: The name of this EdgeLine.
        :type: str
        """
        self._name = name

    @property
    def schema(self):
        """
        Gets the schema of this EdgeLine.


        :return: The schema of this EdgeLine.
        :rtype: UriReference
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this EdgeLine.


        :param schema: The schema of this EdgeLine.
        :type: UriReference
        """
        self._schema = schema

    @property
    def properties(self):
        """
        Gets the properties of this EdgeLine.


        :return: The properties of this EdgeLine.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this EdgeLine.


        :param properties: The properties of this EdgeLine.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def edge(self):
        """
        Gets the edge of this EdgeLine.


        :return: The edge of this EdgeLine.
        :rtype: Edge
        """
        return self._edge

    @edge.setter
    def edge(self, edge):
        """
        Sets the edge of this EdgeLine.


        :param edge: The edge of this EdgeLine.
        :type: Edge
        """
        self._edge = edge

    @property
    def edge_group(self):
        """
        Gets the edge_group of this EdgeLine.


        :return: The edge_group of this EdgeLine.
        :rtype: EdgeGroup
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this EdgeLine.


        :param edge_group: The edge_group of this EdgeLine.
        :type: EdgeGroup
        """
        self._edge_group = edge_group

    @property
    def line_type(self):
        """
        Gets the line_type of this EdgeLine.


        :return: The line_type of this EdgeLine.
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """
        Sets the line_type of this EdgeLine.


        :param line_type: The line_type of this EdgeLine.
        :type: str
        """
        allowed_values = ["TIE", "NETWORK", "TRUNK", "STATION"]
        if line_type not in allowed_values:
            raise ValueError(
                "Invalid value for `line_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._line_type = line_type

    @property
    def endpoint(self):
        """
        Gets the endpoint of this EdgeLine.


        :return: The endpoint of this EdgeLine.
        :rtype: Endpoint
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this EdgeLine.


        :param endpoint: The endpoint of this EdgeLine.
        :type: Endpoint
        """
        self._endpoint = endpoint

    @property
    def ip_address(self):
        """
        Gets the ip_address of this EdgeLine.


        :return: The ip_address of this EdgeLine.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this EdgeLine.


        :param ip_address: The ip_address of this EdgeLine.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def logical_interface_id(self):
        """
        Gets the logical_interface_id of this EdgeLine.


        :return: The logical_interface_id of this EdgeLine.
        :rtype: str
        """
        return self._logical_interface_id

    @logical_interface_id.setter
    def logical_interface_id(self, logical_interface_id):
        """
        Sets the logical_interface_id of this EdgeLine.


        :param logical_interface_id: The logical_interface_id of this EdgeLine.
        :type: str
        """
        self._logical_interface_id = logical_interface_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EdgeLine.
        The URI for this object

        :return: The self_uri of this EdgeLine.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EdgeLine.
        The URI for this object

        :param self_uri: The self_uri of this EdgeLine.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Account(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Account - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'org_legal_name': 'str',
            'billing_address_line1': 'str',
            'billing_address_line2': 'str',
            'billing_address_city': 'str',
            'billing_address_state': 'str',
            'billing_address_zip_code': 'str',
            'billing_address_country': 'str',
            'legal_address_line1': 'str',
            'legal_address_line2': 'str',
            'legal_address_city': 'str',
            'legal_address_state': 'str',
            'legal_address_zip_code': 'str',
            'legal_address_country': 'str',
            'billing_contact_first_name': 'str',
            'billing_contact_last_name': 'str',
            'billing_contact_email': 'str',
            'billing_contact_phone': 'str',
            'purchase_order_number': 'str',
            'is_tax_exempt': 'bool',
            'currency': 'str',
            'payment_term': 'str',
            'contract_term': 'int',
            'auto_renew': 'bool',
            'enabled': 'bool',
            'min_commit_quantities': 'dict(str, int)',
            'estimated_quantities': 'dict(str, int)',
            'one_time_charges': 'list[str]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'org_legal_name': 'orgLegalName',
            'billing_address_line1': 'billingAddressLine1',
            'billing_address_line2': 'billingAddressLine2',
            'billing_address_city': 'billingAddressCity',
            'billing_address_state': 'billingAddressState',
            'billing_address_zip_code': 'billingAddressZipCode',
            'billing_address_country': 'billingAddressCountry',
            'legal_address_line1': 'legalAddressLine1',
            'legal_address_line2': 'legalAddressLine2',
            'legal_address_city': 'legalAddressCity',
            'legal_address_state': 'legalAddressState',
            'legal_address_zip_code': 'legalAddressZipCode',
            'legal_address_country': 'legalAddressCountry',
            'billing_contact_first_name': 'billingContactFirstName',
            'billing_contact_last_name': 'billingContactLastName',
            'billing_contact_email': 'billingContactEmail',
            'billing_contact_phone': 'billingContactPhone',
            'purchase_order_number': 'purchaseOrderNumber',
            'is_tax_exempt': 'isTaxExempt',
            'currency': 'currency',
            'payment_term': 'paymentTerm',
            'contract_term': 'contractTerm',
            'auto_renew': 'autoRenew',
            'enabled': 'enabled',
            'min_commit_quantities': 'minCommitQuantities',
            'estimated_quantities': 'estimatedQuantities',
            'one_time_charges': 'oneTimeCharges',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._org_legal_name = None
        self._billing_address_line1 = None
        self._billing_address_line2 = None
        self._billing_address_city = None
        self._billing_address_state = None
        self._billing_address_zip_code = None
        self._billing_address_country = None
        self._legal_address_line1 = None
        self._legal_address_line2 = None
        self._legal_address_city = None
        self._legal_address_state = None
        self._legal_address_zip_code = None
        self._legal_address_country = None
        self._billing_contact_first_name = None
        self._billing_contact_last_name = None
        self._billing_contact_email = None
        self._billing_contact_phone = None
        self._purchase_order_number = None
        self._is_tax_exempt = False
        self._currency = None
        self._payment_term = None
        self._contract_term = None
        self._auto_renew = False
        self._enabled = False
        self._min_commit_quantities = None
        self._estimated_quantities = None
        self._one_time_charges = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Account.
        The globally unique identifier for the object.

        :return: The id of this Account.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Account.
        The globally unique identifier for the object.

        :param id: The id of this Account.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Account.


        :return: The name of this Account.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Account.


        :param name: The name of this Account.
        :type: str
        """
        self._name = name

    @property
    def org_legal_name(self):
        """
        Gets the org_legal_name of this Account.


        :return: The org_legal_name of this Account.
        :rtype: str
        """
        return self._org_legal_name

    @org_legal_name.setter
    def org_legal_name(self, org_legal_name):
        """
        Sets the org_legal_name of this Account.


        :param org_legal_name: The org_legal_name of this Account.
        :type: str
        """
        self._org_legal_name = org_legal_name

    @property
    def billing_address_line1(self):
        """
        Gets the billing_address_line1 of this Account.


        :return: The billing_address_line1 of this Account.
        :rtype: str
        """
        return self._billing_address_line1

    @billing_address_line1.setter
    def billing_address_line1(self, billing_address_line1):
        """
        Sets the billing_address_line1 of this Account.


        :param billing_address_line1: The billing_address_line1 of this Account.
        :type: str
        """
        self._billing_address_line1 = billing_address_line1

    @property
    def billing_address_line2(self):
        """
        Gets the billing_address_line2 of this Account.


        :return: The billing_address_line2 of this Account.
        :rtype: str
        """
        return self._billing_address_line2

    @billing_address_line2.setter
    def billing_address_line2(self, billing_address_line2):
        """
        Sets the billing_address_line2 of this Account.


        :param billing_address_line2: The billing_address_line2 of this Account.
        :type: str
        """
        self._billing_address_line2 = billing_address_line2

    @property
    def billing_address_city(self):
        """
        Gets the billing_address_city of this Account.


        :return: The billing_address_city of this Account.
        :rtype: str
        """
        return self._billing_address_city

    @billing_address_city.setter
    def billing_address_city(self, billing_address_city):
        """
        Sets the billing_address_city of this Account.


        :param billing_address_city: The billing_address_city of this Account.
        :type: str
        """
        self._billing_address_city = billing_address_city

    @property
    def billing_address_state(self):
        """
        Gets the billing_address_state of this Account.


        :return: The billing_address_state of this Account.
        :rtype: str
        """
        return self._billing_address_state

    @billing_address_state.setter
    def billing_address_state(self, billing_address_state):
        """
        Sets the billing_address_state of this Account.


        :param billing_address_state: The billing_address_state of this Account.
        :type: str
        """
        self._billing_address_state = billing_address_state

    @property
    def billing_address_zip_code(self):
        """
        Gets the billing_address_zip_code of this Account.


        :return: The billing_address_zip_code of this Account.
        :rtype: str
        """
        return self._billing_address_zip_code

    @billing_address_zip_code.setter
    def billing_address_zip_code(self, billing_address_zip_code):
        """
        Sets the billing_address_zip_code of this Account.


        :param billing_address_zip_code: The billing_address_zip_code of this Account.
        :type: str
        """
        self._billing_address_zip_code = billing_address_zip_code

    @property
    def billing_address_country(self):
        """
        Gets the billing_address_country of this Account.


        :return: The billing_address_country of this Account.
        :rtype: str
        """
        return self._billing_address_country

    @billing_address_country.setter
    def billing_address_country(self, billing_address_country):
        """
        Sets the billing_address_country of this Account.


        :param billing_address_country: The billing_address_country of this Account.
        :type: str
        """
        self._billing_address_country = billing_address_country

    @property
    def legal_address_line1(self):
        """
        Gets the legal_address_line1 of this Account.


        :return: The legal_address_line1 of this Account.
        :rtype: str
        """
        return self._legal_address_line1

    @legal_address_line1.setter
    def legal_address_line1(self, legal_address_line1):
        """
        Sets the legal_address_line1 of this Account.


        :param legal_address_line1: The legal_address_line1 of this Account.
        :type: str
        """
        self._legal_address_line1 = legal_address_line1

    @property
    def legal_address_line2(self):
        """
        Gets the legal_address_line2 of this Account.


        :return: The legal_address_line2 of this Account.
        :rtype: str
        """
        return self._legal_address_line2

    @legal_address_line2.setter
    def legal_address_line2(self, legal_address_line2):
        """
        Sets the legal_address_line2 of this Account.


        :param legal_address_line2: The legal_address_line2 of this Account.
        :type: str
        """
        self._legal_address_line2 = legal_address_line2

    @property
    def legal_address_city(self):
        """
        Gets the legal_address_city of this Account.


        :return: The legal_address_city of this Account.
        :rtype: str
        """
        return self._legal_address_city

    @legal_address_city.setter
    def legal_address_city(self, legal_address_city):
        """
        Sets the legal_address_city of this Account.


        :param legal_address_city: The legal_address_city of this Account.
        :type: str
        """
        self._legal_address_city = legal_address_city

    @property
    def legal_address_state(self):
        """
        Gets the legal_address_state of this Account.


        :return: The legal_address_state of this Account.
        :rtype: str
        """
        return self._legal_address_state

    @legal_address_state.setter
    def legal_address_state(self, legal_address_state):
        """
        Sets the legal_address_state of this Account.


        :param legal_address_state: The legal_address_state of this Account.
        :type: str
        """
        self._legal_address_state = legal_address_state

    @property
    def legal_address_zip_code(self):
        """
        Gets the legal_address_zip_code of this Account.


        :return: The legal_address_zip_code of this Account.
        :rtype: str
        """
        return self._legal_address_zip_code

    @legal_address_zip_code.setter
    def legal_address_zip_code(self, legal_address_zip_code):
        """
        Sets the legal_address_zip_code of this Account.


        :param legal_address_zip_code: The legal_address_zip_code of this Account.
        :type: str
        """
        self._legal_address_zip_code = legal_address_zip_code

    @property
    def legal_address_country(self):
        """
        Gets the legal_address_country of this Account.


        :return: The legal_address_country of this Account.
        :rtype: str
        """
        return self._legal_address_country

    @legal_address_country.setter
    def legal_address_country(self, legal_address_country):
        """
        Sets the legal_address_country of this Account.


        :param legal_address_country: The legal_address_country of this Account.
        :type: str
        """
        self._legal_address_country = legal_address_country

    @property
    def billing_contact_first_name(self):
        """
        Gets the billing_contact_first_name of this Account.


        :return: The billing_contact_first_name of this Account.
        :rtype: str
        """
        return self._billing_contact_first_name

    @billing_contact_first_name.setter
    def billing_contact_first_name(self, billing_contact_first_name):
        """
        Sets the billing_contact_first_name of this Account.


        :param billing_contact_first_name: The billing_contact_first_name of this Account.
        :type: str
        """
        self._billing_contact_first_name = billing_contact_first_name

    @property
    def billing_contact_last_name(self):
        """
        Gets the billing_contact_last_name of this Account.


        :return: The billing_contact_last_name of this Account.
        :rtype: str
        """
        return self._billing_contact_last_name

    @billing_contact_last_name.setter
    def billing_contact_last_name(self, billing_contact_last_name):
        """
        Sets the billing_contact_last_name of this Account.


        :param billing_contact_last_name: The billing_contact_last_name of this Account.
        :type: str
        """
        self._billing_contact_last_name = billing_contact_last_name

    @property
    def billing_contact_email(self):
        """
        Gets the billing_contact_email of this Account.


        :return: The billing_contact_email of this Account.
        :rtype: str
        """
        return self._billing_contact_email

    @billing_contact_email.setter
    def billing_contact_email(self, billing_contact_email):
        """
        Sets the billing_contact_email of this Account.


        :param billing_contact_email: The billing_contact_email of this Account.
        :type: str
        """
        self._billing_contact_email = billing_contact_email

    @property
    def billing_contact_phone(self):
        """
        Gets the billing_contact_phone of this Account.


        :return: The billing_contact_phone of this Account.
        :rtype: str
        """
        return self._billing_contact_phone

    @billing_contact_phone.setter
    def billing_contact_phone(self, billing_contact_phone):
        """
        Sets the billing_contact_phone of this Account.


        :param billing_contact_phone: The billing_contact_phone of this Account.
        :type: str
        """
        self._billing_contact_phone = billing_contact_phone

    @property
    def purchase_order_number(self):
        """
        Gets the purchase_order_number of this Account.


        :return: The purchase_order_number of this Account.
        :rtype: str
        """
        return self._purchase_order_number

    @purchase_order_number.setter
    def purchase_order_number(self, purchase_order_number):
        """
        Sets the purchase_order_number of this Account.


        :param purchase_order_number: The purchase_order_number of this Account.
        :type: str
        """
        self._purchase_order_number = purchase_order_number

    @property
    def is_tax_exempt(self):
        """
        Gets the is_tax_exempt of this Account.


        :return: The is_tax_exempt of this Account.
        :rtype: bool
        """
        return self._is_tax_exempt

    @is_tax_exempt.setter
    def is_tax_exempt(self, is_tax_exempt):
        """
        Sets the is_tax_exempt of this Account.


        :param is_tax_exempt: The is_tax_exempt of this Account.
        :type: bool
        """
        self._is_tax_exempt = is_tax_exempt

    @property
    def currency(self):
        """
        Gets the currency of this Account.


        :return: The currency of this Account.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this Account.


        :param currency: The currency of this Account.
        :type: str
        """
        self._currency = currency

    @property
    def payment_term(self):
        """
        Gets the payment_term of this Account.


        :return: The payment_term of this Account.
        :rtype: str
        """
        return self._payment_term

    @payment_term.setter
    def payment_term(self, payment_term):
        """
        Sets the payment_term of this Account.


        :param payment_term: The payment_term of this Account.
        :type: str
        """
        self._payment_term = payment_term

    @property
    def contract_term(self):
        """
        Gets the contract_term of this Account.


        :return: The contract_term of this Account.
        :rtype: int
        """
        return self._contract_term

    @contract_term.setter
    def contract_term(self, contract_term):
        """
        Sets the contract_term of this Account.


        :param contract_term: The contract_term of this Account.
        :type: int
        """
        self._contract_term = contract_term

    @property
    def auto_renew(self):
        """
        Gets the auto_renew of this Account.


        :return: The auto_renew of this Account.
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """
        Sets the auto_renew of this Account.


        :param auto_renew: The auto_renew of this Account.
        :type: bool
        """
        self._auto_renew = auto_renew

    @property
    def enabled(self):
        """
        Gets the enabled of this Account.


        :return: The enabled of this Account.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Account.


        :param enabled: The enabled of this Account.
        :type: bool
        """
        self._enabled = enabled

    @property
    def min_commit_quantities(self):
        """
        Gets the min_commit_quantities of this Account.


        :return: The min_commit_quantities of this Account.
        :rtype: dict(str, int)
        """
        return self._min_commit_quantities

    @min_commit_quantities.setter
    def min_commit_quantities(self, min_commit_quantities):
        """
        Sets the min_commit_quantities of this Account.


        :param min_commit_quantities: The min_commit_quantities of this Account.
        :type: dict(str, int)
        """
        self._min_commit_quantities = min_commit_quantities

    @property
    def estimated_quantities(self):
        """
        Gets the estimated_quantities of this Account.


        :return: The estimated_quantities of this Account.
        :rtype: dict(str, int)
        """
        return self._estimated_quantities

    @estimated_quantities.setter
    def estimated_quantities(self, estimated_quantities):
        """
        Sets the estimated_quantities of this Account.


        :param estimated_quantities: The estimated_quantities of this Account.
        :type: dict(str, int)
        """
        self._estimated_quantities = estimated_quantities

    @property
    def one_time_charges(self):
        """
        Gets the one_time_charges of this Account.


        :return: The one_time_charges of this Account.
        :rtype: list[str]
        """
        return self._one_time_charges

    @one_time_charges.setter
    def one_time_charges(self, one_time_charges):
        """
        Sets the one_time_charges of this Account.


        :param one_time_charges: The one_time_charges of this Account.
        :type: list[str]
        """
        self._one_time_charges = one_time_charges

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Account.
        The URI for this object

        :return: The self_uri of this Account.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Account.
        The URI for this object

        :param self_uri: The self_uri of this Account.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class PolicyErrorMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PolicyErrorMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status_code': 'int',
            'user_message': 'object',
            'user_params_message': 'str',
            'error_code': 'str',
            'correlation_id': 'str',
            'user_params': 'list[UserParam]',
            'insert_date': 'datetime'
        }

        self.attribute_map = {
            'status_code': 'statusCode',
            'user_message': 'userMessage',
            'user_params_message': 'userParamsMessage',
            'error_code': 'errorCode',
            'correlation_id': 'correlationId',
            'user_params': 'userParams',
            'insert_date': 'insertDate'
        }

        self._status_code = None
        self._user_message = None
        self._user_params_message = None
        self._error_code = None
        self._correlation_id = None
        self._user_params = None
        self._insert_date = None

    @property
    def status_code(self):
        """
        Gets the status_code of this PolicyErrorMessage.


        :return: The status_code of this PolicyErrorMessage.
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this PolicyErrorMessage.


        :param status_code: The status_code of this PolicyErrorMessage.
        :type: int
        """
        self._status_code = status_code

    @property
    def user_message(self):
        """
        Gets the user_message of this PolicyErrorMessage.


        :return: The user_message of this PolicyErrorMessage.
        :rtype: object
        """
        return self._user_message

    @user_message.setter
    def user_message(self, user_message):
        """
        Sets the user_message of this PolicyErrorMessage.


        :param user_message: The user_message of this PolicyErrorMessage.
        :type: object
        """
        self._user_message = user_message

    @property
    def user_params_message(self):
        """
        Gets the user_params_message of this PolicyErrorMessage.


        :return: The user_params_message of this PolicyErrorMessage.
        :rtype: str
        """
        return self._user_params_message

    @user_params_message.setter
    def user_params_message(self, user_params_message):
        """
        Sets the user_params_message of this PolicyErrorMessage.


        :param user_params_message: The user_params_message of this PolicyErrorMessage.
        :type: str
        """
        self._user_params_message = user_params_message

    @property
    def error_code(self):
        """
        Gets the error_code of this PolicyErrorMessage.


        :return: The error_code of this PolicyErrorMessage.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this PolicyErrorMessage.


        :param error_code: The error_code of this PolicyErrorMessage.
        :type: str
        """
        self._error_code = error_code

    @property
    def correlation_id(self):
        """
        Gets the correlation_id of this PolicyErrorMessage.


        :return: The correlation_id of this PolicyErrorMessage.
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """
        Sets the correlation_id of this PolicyErrorMessage.


        :param correlation_id: The correlation_id of this PolicyErrorMessage.
        :type: str
        """
        self._correlation_id = correlation_id

    @property
    def user_params(self):
        """
        Gets the user_params of this PolicyErrorMessage.


        :return: The user_params of this PolicyErrorMessage.
        :rtype: list[UserParam]
        """
        return self._user_params

    @user_params.setter
    def user_params(self, user_params):
        """
        Sets the user_params of this PolicyErrorMessage.


        :param user_params: The user_params of this PolicyErrorMessage.
        :type: list[UserParam]
        """
        self._user_params = user_params

    @property
    def insert_date(self):
        """
        Gets the insert_date of this PolicyErrorMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The insert_date of this PolicyErrorMessage.
        :rtype: datetime
        """
        return self._insert_date

    @insert_date.setter
    def insert_date(self, insert_date):
        """
        Sets the insert_date of this PolicyErrorMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param insert_date: The insert_date of this PolicyErrorMessage.
        :type: datetime
        """
        self._insert_date = insert_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CreateShareResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateShareResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'shared_entity_type': 'str',
            'shared_entity': 'UriReference',
            'member_type': 'str',
            'member': 'UriReference',
            'shared_by': 'UriReference',
            'workspace': 'UriReference',
            'succeeded': 'list[Share]',
            'failed': 'list[Share]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'shared_entity_type': 'sharedEntityType',
            'shared_entity': 'sharedEntity',
            'member_type': 'memberType',
            'member': 'member',
            'shared_by': 'sharedBy',
            'workspace': 'workspace',
            'succeeded': 'succeeded',
            'failed': 'failed',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._shared_entity_type = None
        self._shared_entity = None
        self._member_type = None
        self._member = None
        self._shared_by = None
        self._workspace = None
        self._succeeded = None
        self._failed = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CreateShareResponse.
        The globally unique identifier for the object.

        :return: The id of this CreateShareResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CreateShareResponse.
        The globally unique identifier for the object.

        :param id: The id of this CreateShareResponse.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CreateShareResponse.


        :return: The name of this CreateShareResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateShareResponse.


        :param name: The name of this CreateShareResponse.
        :type: str
        """
        self._name = name

    @property
    def shared_entity_type(self):
        """
        Gets the shared_entity_type of this CreateShareResponse.


        :return: The shared_entity_type of this CreateShareResponse.
        :rtype: str
        """
        return self._shared_entity_type

    @shared_entity_type.setter
    def shared_entity_type(self, shared_entity_type):
        """
        Sets the shared_entity_type of this CreateShareResponse.


        :param shared_entity_type: The shared_entity_type of this CreateShareResponse.
        :type: str
        """
        allowed_values = ["DOCUMENT"]
        if shared_entity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `shared_entity_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._shared_entity_type = shared_entity_type

    @property
    def shared_entity(self):
        """
        Gets the shared_entity of this CreateShareResponse.


        :return: The shared_entity of this CreateShareResponse.
        :rtype: UriReference
        """
        return self._shared_entity

    @shared_entity.setter
    def shared_entity(self, shared_entity):
        """
        Sets the shared_entity of this CreateShareResponse.


        :param shared_entity: The shared_entity of this CreateShareResponse.
        :type: UriReference
        """
        self._shared_entity = shared_entity

    @property
    def member_type(self):
        """
        Gets the member_type of this CreateShareResponse.


        :return: The member_type of this CreateShareResponse.
        :rtype: str
        """
        return self._member_type

    @member_type.setter
    def member_type(self, member_type):
        """
        Sets the member_type of this CreateShareResponse.


        :param member_type: The member_type of this CreateShareResponse.
        :type: str
        """
        allowed_values = ["USER", "PUBLIC"]
        if member_type not in allowed_values:
            raise ValueError(
                "Invalid value for `member_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._member_type = member_type

    @property
    def member(self):
        """
        Gets the member of this CreateShareResponse.


        :return: The member of this CreateShareResponse.
        :rtype: UriReference
        """
        return self._member

    @member.setter
    def member(self, member):
        """
        Sets the member of this CreateShareResponse.


        :param member: The member of this CreateShareResponse.
        :type: UriReference
        """
        self._member = member

    @property
    def shared_by(self):
        """
        Gets the shared_by of this CreateShareResponse.


        :return: The shared_by of this CreateShareResponse.
        :rtype: UriReference
        """
        return self._shared_by

    @shared_by.setter
    def shared_by(self, shared_by):
        """
        Sets the shared_by of this CreateShareResponse.


        :param shared_by: The shared_by of this CreateShareResponse.
        :type: UriReference
        """
        self._shared_by = shared_by

    @property
    def workspace(self):
        """
        Gets the workspace of this CreateShareResponse.


        :return: The workspace of this CreateShareResponse.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this CreateShareResponse.


        :param workspace: The workspace of this CreateShareResponse.
        :type: UriReference
        """
        self._workspace = workspace

    @property
    def succeeded(self):
        """
        Gets the succeeded of this CreateShareResponse.


        :return: The succeeded of this CreateShareResponse.
        :rtype: list[Share]
        """
        return self._succeeded

    @succeeded.setter
    def succeeded(self, succeeded):
        """
        Sets the succeeded of this CreateShareResponse.


        :param succeeded: The succeeded of this CreateShareResponse.
        :type: list[Share]
        """
        self._succeeded = succeeded

    @property
    def failed(self):
        """
        Gets the failed of this CreateShareResponse.


        :return: The failed of this CreateShareResponse.
        :rtype: list[Share]
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """
        Sets the failed of this CreateShareResponse.


        :param failed: The failed of this CreateShareResponse.
        :type: list[Share]
        """
        self._failed = failed

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CreateShareResponse.
        The URI for this object

        :return: The self_uri of this CreateShareResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CreateShareResponse.
        The URI for this object

        :param self_uri: The self_uri of this CreateShareResponse.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class RecordingEmailMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecordingEmailMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'html_body': 'str',
            'text_body': 'str',
            'id': 'str',
            'to': 'list[EmailAddress]',
            'cc': 'list[EmailAddress]',
            'bcc': 'list[EmailAddress]',
            'pcFrom': 'EmailAddress',
            'subject': 'str',
            'attachments': 'list[EmailAttachment]',
            'time': 'datetime'
        }

        self.attribute_map = {
            'html_body': 'htmlBody',
            'text_body': 'textBody',
            'id': 'id',
            'to': 'to',
            'cc': 'cc',
            'bcc': 'bcc',
            'pcFrom': 'from',
            'subject': 'subject',
            'attachments': 'attachments',
            'time': 'time'
        }

        self._html_body = None
        self._text_body = None
        self._id = None
        self._to = None
        self._cc = None
        self._bcc = None
        self._pcFrom = None
        self._subject = None
        self._attachments = None
        self._time = None

    @property
    def html_body(self):
        """
        Gets the html_body of this RecordingEmailMessage.


        :return: The html_body of this RecordingEmailMessage.
        :rtype: str
        """
        return self._html_body

    @html_body.setter
    def html_body(self, html_body):
        """
        Sets the html_body of this RecordingEmailMessage.


        :param html_body: The html_body of this RecordingEmailMessage.
        :type: str
        """
        self._html_body = html_body

    @property
    def text_body(self):
        """
        Gets the text_body of this RecordingEmailMessage.


        :return: The text_body of this RecordingEmailMessage.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this RecordingEmailMessage.


        :param text_body: The text_body of this RecordingEmailMessage.
        :type: str
        """
        self._text_body = text_body

    @property
    def id(self):
        """
        Gets the id of this RecordingEmailMessage.


        :return: The id of this RecordingEmailMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecordingEmailMessage.


        :param id: The id of this RecordingEmailMessage.
        :type: str
        """
        self._id = id

    @property
    def to(self):
        """
        Gets the to of this RecordingEmailMessage.


        :return: The to of this RecordingEmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._to

    @to.setter
    def to(self, to):
        """
        Sets the to of this RecordingEmailMessage.


        :param to: The to of this RecordingEmailMessage.
        :type: list[EmailAddress]
        """
        self._to = to

    @property
    def cc(self):
        """
        Gets the cc of this RecordingEmailMessage.


        :return: The cc of this RecordingEmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """
        Sets the cc of this RecordingEmailMessage.


        :param cc: The cc of this RecordingEmailMessage.
        :type: list[EmailAddress]
        """
        self._cc = cc

    @property
    def bcc(self):
        """
        Gets the bcc of this RecordingEmailMessage.


        :return: The bcc of this RecordingEmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """
        Sets the bcc of this RecordingEmailMessage.


        :param bcc: The bcc of this RecordingEmailMessage.
        :type: list[EmailAddress]
        """
        self._bcc = bcc

    @property
    def pcFrom(self):
        """
        Gets the pcFrom of this RecordingEmailMessage.


        :return: The pcFrom of this RecordingEmailMessage.
        :rtype: EmailAddress
        """
        return self._pcFrom

    @pcFrom.setter
    def pcFrom(self, pcFrom):
        """
        Sets the pcFrom of this RecordingEmailMessage.


        :param pcFrom: The pcFrom of this RecordingEmailMessage.
        :type: EmailAddress
        """
        self._pcFrom = pcFrom

    @property
    def subject(self):
        """
        Gets the subject of this RecordingEmailMessage.


        :return: The subject of this RecordingEmailMessage.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this RecordingEmailMessage.


        :param subject: The subject of this RecordingEmailMessage.
        :type: str
        """
        self._subject = subject

    @property
    def attachments(self):
        """
        Gets the attachments of this RecordingEmailMessage.


        :return: The attachments of this RecordingEmailMessage.
        :rtype: list[EmailAttachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """
        Sets the attachments of this RecordingEmailMessage.


        :param attachments: The attachments of this RecordingEmailMessage.
        :type: list[EmailAttachment]
        """
        self._attachments = attachments

    @property
    def time(self):
        """
        Gets the time of this RecordingEmailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The time of this RecordingEmailMessage.
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this RecordingEmailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param time: The time of this RecordingEmailMessage.
        :type: datetime
        """
        self._time = time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CreateCallRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateCallRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'phone_number': 'str',
            'call_from_queue_id': 'str',
            'call_queue_id': 'str',
            'call_user_id': 'str',
            'priority': 'int',
            'language_id': 'str',
            'routing_skills_ids': 'list[str]',
            'conversation_ids': 'list[str]',
            'participants': 'list[Destination]'
        }

        self.attribute_map = {
            'phone_number': 'phoneNumber',
            'call_from_queue_id': 'callFromQueueId',
            'call_queue_id': 'callQueueId',
            'call_user_id': 'callUserId',
            'priority': 'priority',
            'language_id': 'languageId',
            'routing_skills_ids': 'routingSkillsIds',
            'conversation_ids': 'conversationIds',
            'participants': 'participants'
        }

        self._phone_number = None
        self._call_from_queue_id = None
        self._call_queue_id = None
        self._call_user_id = None
        self._priority = None
        self._language_id = None
        self._routing_skills_ids = None
        self._conversation_ids = None
        self._participants = None

    @property
    def phone_number(self):
        """
        Gets the phone_number of this CreateCallRequest.
        The phone number to dial.

        :return: The phone_number of this CreateCallRequest.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this CreateCallRequest.
        The phone number to dial.

        :param phone_number: The phone_number of this CreateCallRequest.
        :type: str
        """
        self._phone_number = phone_number

    @property
    def call_from_queue_id(self):
        """
        Gets the call_from_queue_id of this CreateCallRequest.
        The queue ID to call on behalf of.

        :return: The call_from_queue_id of this CreateCallRequest.
        :rtype: str
        """
        return self._call_from_queue_id

    @call_from_queue_id.setter
    def call_from_queue_id(self, call_from_queue_id):
        """
        Sets the call_from_queue_id of this CreateCallRequest.
        The queue ID to call on behalf of.

        :param call_from_queue_id: The call_from_queue_id of this CreateCallRequest.
        :type: str
        """
        self._call_from_queue_id = call_from_queue_id

    @property
    def call_queue_id(self):
        """
        Gets the call_queue_id of this CreateCallRequest.
        The queue ID to call.

        :return: The call_queue_id of this CreateCallRequest.
        :rtype: str
        """
        return self._call_queue_id

    @call_queue_id.setter
    def call_queue_id(self, call_queue_id):
        """
        Sets the call_queue_id of this CreateCallRequest.
        The queue ID to call.

        :param call_queue_id: The call_queue_id of this CreateCallRequest.
        :type: str
        """
        self._call_queue_id = call_queue_id

    @property
    def call_user_id(self):
        """
        Gets the call_user_id of this CreateCallRequest.
        The user ID to call.

        :return: The call_user_id of this CreateCallRequest.
        :rtype: str
        """
        return self._call_user_id

    @call_user_id.setter
    def call_user_id(self, call_user_id):
        """
        Sets the call_user_id of this CreateCallRequest.
        The user ID to call.

        :param call_user_id: The call_user_id of this CreateCallRequest.
        :type: str
        """
        self._call_user_id = call_user_id

    @property
    def priority(self):
        """
        Gets the priority of this CreateCallRequest.
        The priority to assign to this call (if calling a queue).

        :return: The priority of this CreateCallRequest.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this CreateCallRequest.
        The priority to assign to this call (if calling a queue).

        :param priority: The priority of this CreateCallRequest.
        :type: int
        """
        self._priority = priority

    @property
    def language_id(self):
        """
        Gets the language_id of this CreateCallRequest.
        The language skill ID to use for routing this call (if calling a queue).

        :return: The language_id of this CreateCallRequest.
        :rtype: str
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this CreateCallRequest.
        The language skill ID to use for routing this call (if calling a queue).

        :param language_id: The language_id of this CreateCallRequest.
        :type: str
        """
        self._language_id = language_id

    @property
    def routing_skills_ids(self):
        """
        Gets the routing_skills_ids of this CreateCallRequest.
        The skill ID's to use for routing this call (if calling a queue).

        :return: The routing_skills_ids of this CreateCallRequest.
        :rtype: list[str]
        """
        return self._routing_skills_ids

    @routing_skills_ids.setter
    def routing_skills_ids(self, routing_skills_ids):
        """
        Sets the routing_skills_ids of this CreateCallRequest.
        The skill ID's to use for routing this call (if calling a queue).

        :param routing_skills_ids: The routing_skills_ids of this CreateCallRequest.
        :type: list[str]
        """
        self._routing_skills_ids = routing_skills_ids

    @property
    def conversation_ids(self):
        """
        Gets the conversation_ids of this CreateCallRequest.
        The list of existing call conversations to merge into a new ad-hoc conference.

        :return: The conversation_ids of this CreateCallRequest.
        :rtype: list[str]
        """
        return self._conversation_ids

    @conversation_ids.setter
    def conversation_ids(self, conversation_ids):
        """
        Sets the conversation_ids of this CreateCallRequest.
        The list of existing call conversations to merge into a new ad-hoc conference.

        :param conversation_ids: The conversation_ids of this CreateCallRequest.
        :type: list[str]
        """
        self._conversation_ids = conversation_ids

    @property
    def participants(self):
        """
        Gets the participants of this CreateCallRequest.
        The list of participants to call to create a new ad-hoc conference.

        :return: The participants of this CreateCallRequest.
        :rtype: list[Destination]
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """
        Sets the participants of this CreateCallRequest.
        The list of participants to call to create a new ad-hoc conference.

        :param participants: The participants of this CreateCallRequest.
        :type: list[Destination]
        """
        self._participants = participants

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

